@@ -89,8 +89,8 @@ namespace pan
       virtual const CertStore& get_certstore () const { return _certstore; }
 
     private:
-      EncodeCache _encode_cache;
       ArticleCache _cache;
+      EncodeCache _encode_cache;
       CertStore _certstore;
 
     public:
@@ -112,18 +112,16 @@ namespace pan
 
       void load_server_properties (const DataIO&);
 
-      void save_server_properties (DataIO&) const;
+      void save_server_properties (DataIO&);
 
       typedef Loki::AssocVector<Quark,Server> servers_t;
 
       servers_t _servers;
 
-//      Server* find_server (const Quark& server);
-
     public:
       virtual const Server* find_server (const Quark& server) const;
       virtual Server* find_server (const Quark& server);
-      virtual bool find_server_by_hn (const Quark& server, Quark& setme) const;
+      virtual bool find_server_by_hn (const std::string& server, Quark& setme) const;
 
     public: // mutators
 
@@ -134,7 +132,7 @@ namespace pan
 
       virtual void set_server_auth (const Quark       & server,
                                     const StringView  & username,
-                                    const StringView  & password);
+                                    gchar             *&password);
 
       virtual void set_server_trust (const Quark      & servername,
                                      int                setme);
@@ -168,7 +166,7 @@ namespace pan
 
       virtual bool get_server_auth (const Quark   & server,
                                     std::string   & setme_username,
-                                    std::string   & setme_password) const;
+                                    gchar         *&setme_password);
 
       virtual bool get_server_trust (const Quark  & servername, int&) const;
 
@@ -478,8 +476,8 @@ namespace pan
 
         private: // implementation fields
           const Quark _group;
-          const Quark _save_path;  // for auto-download
           DataImpl & _data;
+          const Quark _save_path;  // for auto-download
           nodes_t _nodes;
           MemChunk<ArticleNode> _node_chunk;
           FilterInfo _filter;
