@@ -156,7 +156,7 @@ namespace pan
 #endif
       int _attachments;
       int _cur_col, _cur_row;
-      std::set<char*> _freeme;
+      std::set<char*> _attach_names;
       MenuSelection _selection;
 
     public:
