@@ -24,6 +24,7 @@
 #include <pan/data/data.h>
 #include "gtk-compat.h"
 #include "group-prefs.h"
+#include "prefs.h"
 
 namespace pan
 {
@@ -32,6 +33,7 @@ namespace pan
     public:
       GroupPrefsDialog (Data            & data,
                         const quarks_v  & groups,
+                        Prefs           & prefs,
                         GroupPrefs      & group_prefs,
                         GtkWindow       * parent_window);
 
@@ -40,16 +42,23 @@ namespace pan
 
     private:
       const quarks_v   _groups;
+      Prefs        & _prefs;
       GroupPrefs   & _group_prefs;
       GtkWidget    * _root;
       GtkWidget    * _charset;
       GtkWidget    * _profile;
       GtkWidget    * _spellchecker_language;
+      GtkWidget    * _group_color;
+      GdkColor       _color;
       GtkWidget    * _save_path;
 
     private:
       static void response_cb (GtkDialog*, int, gpointer);
       void save_from_gui ();
+
+    public:
+      	 GdkColor& get_color() { return _color; }
+      	 GtkWidget* get_color_button() { return _group_color; }
   };
 }
 #endif
