@@ -57,8 +57,8 @@ extern "C" {
   #include "pan.ui.ssl.h"
 #else
   #include "pan.ui.h"
-
 #endif
+
 #include "prefs-ui.h"
 #include "progress-view.h"
 #include "profiles-dialog.h"
@@ -181,10 +181,10 @@ void GUI :: show_task_window_cb (GtkWidget *, gpointer gui_gpointer)
 GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   _data (data),
   _queue (queue),
-  _cache (data.get_cache()),
-  _encode_cache (data.get_encode_cache()),
   _prefs (prefs),
   _group_prefs (group_prefs),
+  _cache (data.get_cache()),
+  _encode_cache (data.get_encode_cache()),
   _root (gtk_vbox_new (FALSE, 0)),
   _menu_vbox (gtk_vbox_new (FALSE, 0)),
   _group_pane (0),
@@ -211,7 +211,7 @@ GUI :: GUI (Data& data, Queue& queue, Prefs& prefs, GroupPrefs& group_prefs):
   gtk_box_pack_start (GTK_BOX(_root), _menu_vbox, FALSE, FALSE, 0);
   gtk_widget_show (_menu_vbox);
 
-  _group_pane = new GroupPane (*this, data, _prefs);
+  _group_pane = new GroupPane (*this, data, _prefs, _group_prefs);
   _header_pane = new HeaderPane (*this, data, _queue, _cache, _prefs, _group_prefs, *this, *this);
   _body_pane = new BodyPane (data, _cache, _prefs, _group_prefs, _queue, _header_pane);
 
@@ -358,6 +358,7 @@ namespace
 {
   GtkWidget * hpane (0);
   GtkWidget * vpane (0);
+  GtkWidget * sep_vpane (0);
 }
 
 GUI :: ~GUI ()
@@ -379,6 +380,11 @@ GUI :: ~GUI ()
     res = gtk_paned_get_position(GTK_PANED(vpane));
     if (res > 0) _prefs.set_int ("main-window-vpane-position", res);
   }
+  if (sep_vpane)
+  {
+    res = gtk_paned_get_position(GTK_PANED(sep_vpane));
+    if (res > 0) _prefs.set_int ("sep-vpane-position", res);
+  }
 
 
   const bool maximized = gtk_widget_get_window(_root)
@@ -894,7 +900,7 @@ void GUI :: do_show_group_preferences_dialog ()
 {
   quarks_v groups(_group_pane->get_full_selection());
   if (!groups.empty()) {
-    GroupPrefsDialog * dialog = new GroupPrefsDialog (_data, groups, _group_prefs, get_window(_root));
+    GroupPrefsDialog * dialog = new GroupPrefsDialog (_data, groups, _prefs, _group_prefs, get_window(_root));
     gtk_widget_show (dialog->root());
   }
 }
@@ -1410,8 +1416,6 @@ bool GUI :: confirm_accept_new_cert_dialog(GtkWindow * parent, gnutls_x509_crt_t
     GTK_MESSAGE_WARNING,
     GTK_BUTTONS_NONE, NULL);
 
-  gtk_dialog_add_button (GTK_DIALOG(d), _("Always trust"), -66);
-
   HIG :: message_dialog_set_text (GTK_MESSAGE_DIALOG(d), buf,
     _("Do you want to accept it permanently? (You can change this later.)"));
   gtk_dialog_add_buttons (GTK_DIALOG(d),
@@ -1422,15 +1426,16 @@ bool GUI :: confirm_accept_new_cert_dialog(GtkWindow * parent, gnutls_x509_crt_t
 
   gint ret_code = gtk_dialog_run (GTK_DIALOG(d));
 
-  if (ret_code == -66)
+  if (ret_code == GTK_RESPONSE_YES)
   {
+    debug_SSL("set server trust to enabled");
     _data.set_server_trust (server, 1);
     _data.save_server_info(server);
   }
 
   gtk_widget_destroy(d);
 
-  return ret_code == GTK_RESPONSE_YES || ret_code == -66;
+  return ret_code == GTK_RESPONSE_YES;
 }
 #endif
 
@@ -1627,11 +1632,28 @@ namespace
 
     GtkWidget * w;
     if (w1!=NULL && w2!=NULL) {
-      int pos = uglyhack_idx==0
-        ? prefs.get_int ("main-window-vpane-position", 300)
-        : prefs.get_int ("main-window-hpane-position", 266);
+      int pos(0);
+      if (uglyhack_idx==0)
+      {
+        pos = prefs.get_int ("main-window-vpane-position", 300);
+      }
+      else if (uglyhack_idx==1)
+      {
+        pos = prefs.get_int ("main-window-hpane-position", 266);
+      }
+      else if (uglyhack_idx==2)
+      {
+        pos = prefs.get_int ("sep-vpane-position", 266);
+      }
       if (orient == VERTICAL) {
-        w = vpane = gtk_vpaned_new ();
+        if (uglyhack_idx==0)
+        {
+          w = vpane = gtk_vpaned_new ();
+        }
+        else if (uglyhack_idx==2)
+        {
+          w = sep_vpane = gtk_vpaned_new ();
+        }
         gtk_widget_set_size_request (w1, -1, 50);
         gtk_widget_set_size_request (w2, -1, 50);
       } else {
@@ -1733,7 +1755,7 @@ void GUI :: do_tabbed_layout (bool tabbed)
       w = pack_widgets (_prefs, w, p[2], HORIZONTAL, 1);
     } else if (layout == "stacked-vertical") {
       w = pack_widgets (_prefs, p[0], p[1], VERTICAL, 0);
-      w = pack_widgets (_prefs, w, p[2], VERTICAL, 1);
+      w = pack_widgets (_prefs, w, p[2], VERTICAL, 2);
     } else { // stacked right
       w = pack_widgets (_prefs, p[1], p[2], VERTICAL, 0);
       w = pack_widgets (_prefs, p[0], w,    HORIZONTAL, 1);
@@ -1847,7 +1869,6 @@ void GUI :: do_show_selected_article_info ()
     foreach_const (std::set<number_t>, missing_parts, it)
       s << ' ' << *it;
 
-
     const char* author = iconv_inited ? __g_mime_iconv_strdup(conv, a->author.c_str()) : a->author.c_str();
     const char* subject = iconv_inited ? __g_mime_iconv_strdup(conv, a->subject.c_str()) : a->subject.c_str();
 
@@ -2171,6 +2192,7 @@ GUI :: set_queue_size_label (unsigned int running,
     g_snprintf (str, sizeof(str), "%s: %u/%u", _("Tasks"), running, size);
 
   // build the tooltip
+  // todo : perhaps fix this for mac osx automatically....
   gulong queued, unused, stopped;
   guint64 KiB_remain;
   double KiBps;
@@ -2257,7 +2279,7 @@ GUI :: on_prefs_string_changed (const StringView& key, const StringView& value)
   {
     _prefs.save();
     StringView tmp(value);
-    // default to "eml" if value is empty to conform with article-cache
+    // default to "eml" if value is empty to conform to article-cache
     if (tmp.empty()) tmp ="eml";
     _data.get_cache().set_msg_extension(tmp);
   }
@@ -2306,6 +2328,7 @@ GUI :: on_valid_cert_added (gnutls_x509_crt_t cert, std::string server)
 {
   /* whitelist to make avaible for nntp-pool */
   _certstore.whitelist(server);
+  debug_SSL("whitelist ("<<server<<") ("<<cert<<")");
 }
 
 
