@@ -119,6 +119,9 @@ namespace
   {
     std::cerr << "Shutting down Pan." << std::endl;
     signal (signum, SIG_DFL);
+
+    _dbg_file.close();
+
     mainloop_quit ();
   }
 #endif // G_OS_WIN32
@@ -213,6 +216,7 @@ namespace
     static gboolean status_icon_periodic_refresh (gpointer p)
     {
       static_cast<StatusIconListener*>(p)->update_status_tooltip();
+      return true;
     }
 
 #ifdef HAVE_LIBNOTIFY
@@ -241,8 +245,8 @@ namespace
     bool n() { return notif_shown; }
 
     StatusIconListener(GtkStatusIcon * i, GtkWidget* r, Prefs& p, Queue& q, Data& d, bool v) :
-      icon(i), root(r), prefs(p), queue(q), data(d),
-      tasks_active(0), tasks_total(0), minimized(v), notif_shown(false)
+      icon(i), root(r), prefs(p), queue(q), data(d), minimized(v),
+      tasks_active(0), tasks_total(0), notif_shown(false)
     {
       prefs.add_listener(this);
       queue.add_listener(this);
@@ -320,7 +324,15 @@ namespace
       NotifyNotification *notif(0);
       GError* error(0);
 
-      notif = notify_notification_new (summary, body, NULL);
+#ifdef NOTIFY_CHECK_VERSION
+  #if NOTIFY_CHECK_VERSION (0, 7, 0)
+      notif=notify_notification_new(summary, body, NULL);
+  #else
+      notif=notify_notification_new(summary, body, NULL,NULL);
+  #endif
+#else
+      notif=notify_notification_new(summary, body, NULL,NULL);
+#endif
       if (!notif) return;
 
       _notifs.insert(G_OBJECT(notif));
@@ -629,11 +641,11 @@ _("General Options\n"
     EncodeCache& encode_cache;
     Prefs& prefs;
     GroupPrefs& group_prefs;
-    int dbus_id;
-    bool name_valid;
-    bool lost_name;
-
     GDBusNodeInfo * busnodeinfo;
+    int dbus_id;
+    bool lost_name;
+    bool name_valid;
+
     GDBusInterfaceVTable ifacetable;
 
     Pan(Data& d, Queue& q, ArticleCache& c, EncodeCache& ec, Prefs& p, GroupPrefs& gp) :
@@ -657,7 +669,7 @@ _("General Options\n"
     Pan* pan(static_cast<Pan*>(user_data));
     if (!pan) return;
 
-    gboolean gui(false), nzb(false);
+    gboolean nzb(false);
     gchar* groups;
     gchar* nzb_output_path;
     gchar* nzbs;
@@ -665,19 +677,18 @@ _("General Options\n"
 
     if (g_strcmp0 (method_name, "NZBEnqueue") == 0)
     {
-      g_variant_get (parameters, "(sssbb)", &groups, &nzb_output_path, &nzbs, &gui, &nzb);
+      g_variant_get (parameters, "(sssb)", &groups, &nzb_output_path, &nzbs, &nzb);
 
-      if (groups)
-        if (strlen(groups)!=0)
-        {
-          StringView tok, v(groups);
-          while (v.pop_token(tok,','))
-            pan->queue.add_task (new TaskXOver (pan->data, tok, TaskXOver::NEW), Queue::BOTTOM);
-        }
+      if (groups && strlen(groups)!=0)
+      {
+        StringView tok, v(groups);
+        while (v.pop_token(tok,','))
+          pan->queue.add_task (new TaskXOver (pan->data, tok, TaskXOver::NEW), Queue::BOTTOM);
+      }
 
       if (nzb && nzbs)
       {
-        //parse the files
+        //parse the file list
         StringView tok, nzb(nzbs);
         while (nzb.pop_token(tok))
           nzb_files.push_back(tok);
@@ -702,7 +713,6 @@ _("General Options\n"
   "      <arg type='s' name='groups'    direction='in'/>"
   "      <arg type='s' name='nzb_files' direction='in'/>"
   "      <arg type='s' name='nzb_path'  direction='in'/>"
-  "      <arg type='b' name='gui'       direction='in'/>"
   "      <arg type='b' name='nzb'       direction='in'/>"
   "    </method>"
   "  </interface>"
@@ -834,6 +844,13 @@ main (int argc, char *argv[])
       else _debug_flag = true;
     } else if (!strcmp (tok, "--nzb"))
       nzb = true;
+
+    // undocumented, internal(!) debug flag for ssl problems (after 0.136)
+    else if (!strcmp (tok, "--debug-ssl")) {
+      _dbg_ssl = true;
+      _dbg_file.open("ssl.debug");
+    }
+
     else if (!strcmp (tok, "--version") || !strcmp (tok, "-v"))
       { std::cerr << "Pan " << VERSION << '\n'; return EXIT_SUCCESS; }
     else if (!strcmp (tok, "-o") && i<argc-1)
@@ -896,8 +913,7 @@ main (int argc, char *argv[])
     WorkerPool worker_pool (4, true);
     SocketCreator socket_creator(data, certstore);
     Queue queue (data, data, &socket_creator, certstore, worker_pool, false, 32768);
-
-    data.set_queue(&queue);
+    data.set_queue (&queue);
 
 #ifdef HAVE_DBUS
     Pan pan(data, queue, cache, encode_cache, prefs, group_prefs);
@@ -917,7 +933,7 @@ main (int argc, char *argv[])
                                PAN_DBUS_SERVICE_PATH,
                                "news.pan.NZB",
                                "NZBEnqueue",
-                               g_variant_new ("(sssbb)",
+                               g_variant_new ("(sssb)",
                                   groups.c_str(), nzb_output_path.c_str(), nzb_str.c_str(),  gui, nzb),
                                NULL,
                                G_DBUS_CALL_FLAGS_NONE,
@@ -939,6 +955,8 @@ main (int argc, char *argv[])
   #endif
     _fail:
 #endif
+
+    // set queue prefs _after_ initializing dbus
     queue.set_online(true);
     queue.set_task_save_delay(prefs.get_int ("task-save-delay-secs", 10));
 
@@ -1016,6 +1034,7 @@ main (int argc, char *argv[])
       run_pan_in_window (gui_ptr, data, queue, prefs, group_prefs, GTK_WINDOW(window));
     }
 
+    // free status icons
     for (guint i=0; i<NUM_STATUS_ICONS; ++i)
       g_object_unref(status_icons[i].pixbuf);
     delete _status_icon;
@@ -1028,11 +1047,25 @@ main (int argc, char *argv[])
     }
 
     delete queue_and_gui;
+
+  // free dbus pan struct and handle
 #ifdef HAVE_DBUS
   #ifndef DEBUG_PARALLEL
     pan_dbus_deinit(&pan);
   #endif
 #endif
+
+#ifdef HAVE_GKR
+    // free secure passwords
+    foreach(quarks_t, data.get_servers(), it)
+    {
+      Data::Server* s(data.find_server(*it));
+      if (s && s->gkr_pw)
+      {
+        gnome_keyring_memory_free(s->gkr_pw);
+      }
+    }
+#endif
   }
 
   g_mime_shutdown ();
