@@ -4,7 +4,7 @@
  * Copyright (C) 2002-2006  Charles Kerr <charles@rebelbase.com>
  *
  * This file
- * Copyright (C) 2011 Heinrich Mller <sphemuel@stud.informatik.uni-erlangen.de>
+ * Copyright (C) 2011 Heinrich Mller <henmull@src.gnome.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -308,6 +308,8 @@ namespace
     gnutls_deinit (chan->session);
     g_free(chan->host);
     g_free(chan);
+    // free callback struct
+    delete (mydata_t*)gnutls_session_get_ptr (chan->session);
   }
 }
 
@@ -407,9 +409,8 @@ namespace
   GIOStatus gnutls_seek(GIOChannel *handle, gint64 offset, GSeekType type, GError **gerr)
   {
     GIOGnuTLSChannel *chan = (GIOGnuTLSChannel *)handle;
-    GIOError e;
-    e = g_io_channel_seek(chan->giochan, offset, type);
-    return (e == G_IO_ERROR_NONE) ? G_IO_STATUS_NORMAL : G_IO_STATUS_ERROR;
+    g_io_channel_seek_position(chan->giochan, offset, type, gerr);
+    return !gerr ? G_IO_STATUS_NORMAL : G_IO_STATUS_ERROR;
   }
 
   GIOStatus gnutls_close(GIOChannel *handle, GError **gerr)
@@ -569,17 +570,17 @@ GIOChannelSocketGnuTLS :: _gnutls_handshake (GIOChannel *channel)
   g_return_val_if_fail (chan->session, G_IO_STATUS_ERROR);
 
   /* init custom data for callback */
-  mydata_t mydata;
+  mydata_t* mydata = new mydata_t();
 
-  mydata.cs = &_certstore;
+  mydata->cs = &_certstore;
   Quark setme;
-  _data.find_server_by_hn(_host.c_str(), setme);
-  mydata.host = setme;
-  mydata.hostname_full = _host;
+  _data.find_server_by_hn(_host, setme);
+  mydata->host = setme;
+  mydata->hostname_full = _host;
   int res(0); // always trust server cert
   _data.get_server_trust (setme, res);
-  mydata.always_trust = res;
-  gnutls_session_set_ptr (chan->session, (void *) &mydata);
+  mydata->always_trust = res;
+  gnutls_session_set_ptr (chan->session, (void *) mydata);
 
   int status = gnutls_handshake (chan->session);
 
@@ -836,6 +837,7 @@ GIOChannelSocketGnuTLS :: gnutls_get_iochannel(GIOChannel* channel, const char*
 void
 GIOChannelSocketGnuTLS :: on_verify_cert_failed (gnutls_x509_crt_t cert, std::string server, int nr)
 {
+   debug_SSL("on_verify_cert_failed "<<server<<" "<<nr);
   _certstore.blacklist(server);
 }
 
